// Copyright 2020 Seth Troisi
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#pragma once

#include <Python.h>

extern const char doc_sieve_interval[];
extern const char doc_sieve_factor_interval[];
extern const char doc_sieve_limit[];

PyObject* sieve_interval(PyObject *self, PyObject *args);
PyObject* sieve_factor_interval(PyObject *self, PyObject *args);
PyObject* sieve_limit(PyObject *self, PyObject *args);
